Skip to main content Module store Copy item path Source Batch A batch of write operations that execute all-or-nothing.
On failure, files written during the batch are rolled back. BatchCollection A scoped handle for queuing batch writes to a specific collection. Collection A handle to a collection within a store.
Provides CRUD operations using serde_yaml::Value for dynamic data. Store The main entry point for GroundDB.
Opens a data directory, parses the schema, manages the system database,
and provides collection handles for CRUD operations. SubscriptionId Unique subscription identifier. ChangeEvent An event describing a change to a document in a collection.